<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * A generic and pretty abstract control.
 * Allows for great manipulation using the field's "choices" argumnent.
 */
class Hoo_Control_Generic extends WP_Customize_Control {

	/**
	 * The control type.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'hoo-generic';

	/**
	 * Used to automatically generate all CSS output.
	 *
	 * @access public
	 * @var array
	 */
	public $output = array();

	/**
	 * Data type
	 *
	 * @access public
	 * @var string
	 */
	public $option_type = 'theme_mod';

	/**
	 * Enqueue control related scripts/styles.
	 *
	 * @access public
	 */
	public function enqueue() {

		if ( class_exists( 'Hoo_Custom_Build' ) ) {
			Hoo_Custom_Build::register_dependency( 'jquery' );
			Hoo_Custom_Build::register_dependency( 'customize-base' );
		}

		if ( ! class_exists( 'Hoo_Custom_Build' ) || ! Hoo_Custom_Build::is_custom_build() ) {
			wp_enqueue_script( 'hoo-generic', trailingslashit( Hoo::$url ) . 'controls/generic/generic.js', array( 'jquery', 'customize-base' ), false, true );
			wp_enqueue_style( 'hoo-generic-css', trailingslashit( Hoo::$url ) . 'controls/generic/generic.css', null );
		}
	}

	/**
	 * Refresh the parameters passed to the JavaScript via JSON.
	 *
	 * @see WP_Customize_Control::to_json()
	 */
	public function to_json() {
		parent::to_json();

		$this->json['default'] = $this->setting->default;
		if ( isset( $this->default ) ) {
			$this->json['default'] = $this->default;
		}
		$this->json['output']  = $this->output;
		$this->json['value']   = $this->value();
		$this->json['choices'] = $this->choices;
		$this->json['link']    = $this->get_link();
		$this->json['id']      = $this->id;

		$this->json['inputAttrs'] = '';
		foreach ( $this->input_attrs as $attr => $value ) {
			$this->json['inputAttrs'] .= $attr . '="' . esc_attr( $value ) . '" ';
		}

	}

	/**
	 * An Underscore (JS) template for this control's content (but not its container).
	 *
	 * Class variables for this control class are available in the `data` JS object;
	 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
	 *
	 * @see WP_Customize_Control::print_template()
	 *
	 * @access protected
	 */
	protected function content_template() {
		?>
		<div class="hoo-controls-loading-spinner"><div class="bounce1"></div><div class="bounce2"></div><div class="bounce3"></div></div>
		<label>
			<# if ( data.label ) { #><span class="customize-control-title">{{{ data.label }}}</span><# } #>
			<# if ( data.description ) { #><span class="description customize-control-description">{{{ data.description }}}</span><# } #>
			<div class="customize-control-content">
				<# if ( 'textarea' == data.choices['element'] ) { #>
					<textarea {{{ data.inputAttrs }}} {{{ data.link }}} <# for ( key in data.choices ) { #> {{ key }}="{{ data.choices[ key ] }}"<# } #>>{{ data.value }}</textarea>
				<# } else { #>
					<# var element = ( data.choices.element ) ? data.choices.element : 'input'; #>
					<{{ element }}
						{{{ data.inputAttrs }}}
						value="{{ data.value }}"
						{{{ data.link }}}
						<# for ( key in data.choices ) { #>
							{{ key }}="{{ data.choices[ key ] }}"
						<# } #>
						<# if ( data.choices.content ) { #>
							>{{{ data.choices.content }}}</{{ element }}>
						<# } else { #>
							/>
						<# } #>
				<# } #>
			</div>
		</label>
		<?php
	}
}
